instrumenttools.BassVoice
=========================

.. abjad-lineage:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice

.. autoclass:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassVoice.BassVoice.BassVoice.__repr__
   :noindex:
